import pyttsx3
engine = pyttsx3.init()
engine.say("his package is absolutly useless. Donate to make an actual package at https://paypal.me/thinkerdesign")
print("This package is absolutly useless. Donate to make an actual package at https://paypal.me/thinkerdesign")